@@ -2,5 +2,6 @@ from django import forms
 
 
 class UserModelChoiceField(forms.ModelChoiceField):
+
     def label_from_instance(self, obj):
-        return obj.get_full_name()
+        return obj.get_name_or_username()
